@@ -20,6 +20,10 @@ class Worksheet(_Worksheet):
         self._use_default: Optional[bool] = False
         self.header: Header = None
     
+    @property
+    def read_only(self):
+        return self.parent._read_only
+    
     @property
     def header_row(self):
         '''
